@@ -4,6 +4,6 @@
 __project__ = 'pgraph'
 __author__ = 'Kouhei Maeda'
 __email__ = 'mkouhei@palmtb.net'
-__version__ = '1.0.1'
+__version__ = '1.0.3'
 __repo__ = 'https://github.com/mkouhei/pgraph'
-READTHEDOCS = 'http://pgraph.readthedocs.org'
+READTHEDOCS = 'https://pgraph.readthedocs.org'
